# Copyright 2013-2022 Lawrence Livermore National Security, LLC and other
# Spack Project Developers. See the top-level COPYRIGHT file for details.
#
# SPDX-License-Identifier: (Apache-2.0 OR MIT)

from spack import *


class WfMultiAreaModel(Package):
    """Meta-package to collect all dependencies of the Multi-Area-Model."""

    homepage="https://inm-6.github.io/multi-area-model/"
    #git = "https://github.com/INM-6/multi-area-model"
    git = "https://github.com/terhorstd/multi-area-model"
    maintainer = ["terhorstd"]

    version("master",  branch="master")
    version("ebrains",  branch="lab.ebrains.eu")

    depends_on("py-nested-dict")
    depends_on("py-dicthash")
    depends_on("py-matplotlib")
    depends_on("py-numpy")
    depends_on("py-scipy")
    depends_on("py-future")
    depends_on("nest")
    depends_on("py-notebook", type="test")

    def install(self, spec, prefix):
        # sanity_check_prefix requires something in the install directory
        mkdirp(prefix + "/.spack_test_results")

    @run_after("install")
    @on_package_attributes(run_tests=True)
    def installcheck(self):
        # execute notebook and save
        jupyter = Executable("jupyter")
        jupyter("nbconvert", "--ExecutePreprocessor.kernel_name=python3", "--execute", "--allow-errors", "--to", "notebook", "multi-area-model.ipynb", "--output", prefix+"/.spack_test_results/multi-area-model.ipynb")
